bayespy.utils.misc.CholeskySparse
=================================

.. currentmodule:: bayespy.utils.misc

.. autoclass:: CholeskySparse

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~CholeskySparse.__init__
      ~CholeskySparse.logdet
      ~CholeskySparse.solve
      ~CholeskySparse.trace_solve_gradient
   
   

   
   
   